@@ -2,4 +2,6 @@ from .stack import Stack
 from .queue import Queue
 from .tree import Tree
 from .binarysearchtree import BinarySearchTree
-from .linkedlist import LinkedList
\ No newline at end of file
+from .linkedlist import LinkedList
+from .maxheap import MaxHeap
+from .minheap import MinHeap
\ No newline at end of file
